==> tooltils-1.4.0-py3-none-any.whl: tooltils/info.py <==
"""General installation information"""


from os import listdir


author:  str = 'feetbots'
version: str = '1.4.0'
lines:   int = 0
license: str = """
MIT License

Copyright (c) 2023 feetbots

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

files: list = listdir('./') + ['tooltils/' + i for i in listdir('./tooltils')] + \
              ['tooltils/sys/' + i for i in listdir('./tooltils/sys')] + \
              ['docs/source/' + i for i in listdir('./docs/source/')]

for i in files:
    if '.DS_Store' in i or '__pycache__' in i:
        files.remove(i)
    else:
        try:
            with open(i) as _f:
                lines += len(_f.readlines())
        except (IsADirectoryError, UnicodeDecodeError):
            pass

del listdir, files

==> tooltils-1.4.2-py3-none-any.whl: tooltils/info.py <==
"""General installation information"""


from os import listdir


author:  str = 'feetbots'
version: str = '1.4.2'
lines:   int = 0
license: str = """
MIT License

Copyright (c) 2023 feetbots

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

files: list = listdir('./') + ['tooltils/' + i for i in listdir('./tooltils')] + \
              ['tooltils/sys/' + i for i in listdir('./tooltils/sys')]

for i in files:
    if '.DS_Store' in i or '__pycache__' in i:
        files.remove(i)
    else:
        try:
            with open(i) as _f:
                lines += len(_f.readlines())
        except (IsADirectoryError, UnicodeDecodeError):
            pass

del listdir, files
